(Uncle Profile) เป็นตัวอย่างการอัพโหลด package ไปยัง pypi.org
=============================================================

PyPi: https://pypi.org/project/uncleprofile/

สวัสดีจ้าาาา แพ็คนี้คือแพ็คเกจที่อธิบายโปรไฟล์ของนาย Loong
และสามารถนำไปใช้กับผู้อื่นได้

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install uncleprofile

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from uncleprofile import Profile
   my = Profile('Loong')
   my.company = 'uncle-engineer'
   my.hobby = ['Youtuber','Reading','Sleeping']
   print(my.name)
   my.show_email()
   my.show_myart()
   my.show_hobby()
   my.show_cat()

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer

YouTube: https://www.youtube.com/UncleEngineer
